# PyCalc Permission Package

## What is this? ##
This is a PyCalc django rest framework permission package.

### Using ###

Insert into `settings.py`
```    
    PYCALC_AUTH = {
        'ALGORITHM': 'HS256',
        'REFRESH_SECRET': 'fd%3fgg6!eg',
        'TOKEN_SECRET': 'Fd4f4$%h3g='}
```

---
## Developer ##
My site: